==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/usermanager/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 * @author Otto Vainio <otto@valjakko.net>
 * @author Teemu Mattila <ghcsystems@gmail.com>
 * @author Sami Olmari <sami@olmari.fi>
 */
$lang['menu']                  = 'Käyttäjähallinta';
$lang['noauth']                = '(autentikointi ei ole käytössä)';
$lang['nosupport']             = '(käyttäjähallinta ei ole tuettu)';
$lang['badauth']               = 'Viallinen autentikointimenetelmä';
$lang['user_id']               = 'Käyttäjä';
$lang['user_pass']             = 'Salasana';
$lang['user_name']             = 'Oikea nimi';
$lang['user_mail']             = 'Sähköposti';
$lang['user_groups']           = 'Ryhmät';
$lang['field']                 = 'Kenttä';
$lang['value']                 = 'Arvo';
$lang['add']                   = 'Lisää';
$lang['delete']                = 'Poista';
$lang['delete_selected']       = 'Poista valittu';
$lang['edit']                  = 'Muokkaa';
$lang['edit_prompt']           = 'Muokkaa ryhmää';
$lang['modify']                = 'Tallenna muutokset';
$lang['search']                = 'Hae';
$lang['search_prompt']         = 'Tee haku';
$lang['clear']                 = 'Tyhjennä hakusuodatin';
$lang['filter']                = 'Suodatin';
$lang['summary']               = 'Näytetään käyttäjät %1$d-%2$d / %3$d löytynyttä. %4$d käyttäjää yhteensä.';
$lang['nonefound']             = 'Ei löytynyt käyttäjiä. %d käyttäjää yhteensä.';
$lang['delete_ok']             = '%d käyttäjää poistettu';
$lang['delete_fail']           = '%d poistoa epäonnistui';
$lang['update_ok']             = 'Käyttäjän päivitys onnistui';
$lang['update_fail']           = 'Käyttäjän päivitys epäonnistui';
$lang['update_exists']         = 'Käyttäjän nimen vaihto epäonnistui. Nimi (%s) on jo olemassa (muut muutokset onnistuivat)';
$lang['start']                 = 'alku';
$lang['prev']                  = 'edellinen';
$lang['next']                  = 'seuraava';
$lang['last']                  = 'viimeinen';
$lang['edit_usermissing']      = 'Valittua käyttäjää ei löytynyt. Käyttäjä on voitu päivittää tai poistaa muualta.';
$lang['user_notify']           = 'Tiedota käyttäjälle';
$lang['note_notify']           = 'Tiedotus lähetetään vain, jos käyttäjälle on määritelty uusi salasana.';
$lang['note_group']            = 'Uudelle käyttäjälle määritellään oletusryhmä (%s), jos ryhmää ei erikseen määritellä.';
$lang['note_pass']             = 'Salasana luodaan automaattisesti, mikäli kenttä jätetään tyhjäksi ja jos käyttäjän tiedotus on päällä.';
$lang['add_ok']                = 'Käyttäjä lisätty onnistuneesti';
$lang['add_fail']              = 'Käyttäjän lisäys epäonnistui';
$lang['notify_ok']             = 'Ilmoitus sähköpostilla lähetetty';
$lang['notify_fail']           = 'Ilmoitusta sähköpostilla ei voitu lähettää';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/usermanager/lang/fi/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author otto <otto@valjakko.net>
 * @author Teemu Mattila <ghcsystems@gmail.com>
 * @author Sami Olmari <sami@olmari.fi>
 * @author Jussi Takala <jussi.takala@live.fi>
 */
$lang['menu']                  = 'Käyttäjähallinta';
$lang['noauth']                = '(autentikointi ei ole käytössä)';
$lang['nosupport']             = '(käyttäjähallinta ei ole tuettu)';
$lang['badauth']               = 'Viallinen autentikointimenetelmä';
$lang['user_id']               = 'Käyttäjä';
$lang['user_pass']             = 'Salasana';
$lang['user_name']             = 'Oikea nimi';
$lang['user_mail']             = 'Sähköposti';
$lang['user_groups']           = 'Ryhmät';
$lang['field']                 = 'Kenttä';
$lang['value']                 = 'Arvo';
$lang['add']                   = 'Lisää';
$lang['delete']                = 'Poista';
$lang['delete_selected']       = 'Poista valittu';
$lang['edit']                  = 'Muokkaa';
$lang['edit_prompt']           = 'Muokkaa ryhmää';
$lang['modify']                = 'Tallenna muutokset';
$lang['search']                = 'Hae';
$lang['search_prompt']         = 'Tee haku';
$lang['clear']                 = 'Tyhjennä hakusuodatin';
$lang['filter']                = 'Suodatin';
$lang['import']                = 'Tuo uusia käyttäjiä';
$lang['line']                  = 'Rivi nro.';
$lang['error']                 = 'Vikailmoitus';
$lang['summary']               = 'Näytetään käyttäjät %1$d-%2$d / %3$d löytynyttä. %4$d käyttäjää yhteensä.';
$lang['nonefound']             = 'Ei löytynyt käyttäjiä. %d käyttäjää yhteensä.';
$lang['delete_ok']             = '%d käyttäjää poistettu';
$lang['delete_fail']           = '%d poistoa epäonnistui';
$lang['update_ok']             = 'Käyttäjän päivitys onnistui';
$lang['update_fail']           = 'Käyttäjän päivitys epäonnistui';
$lang['update_exists']         = 'Käyttäjän nimen vaihto epäonnistui. Nimi (%s) on jo olemassa (muut muutokset onnistuivat)';
$lang['start']                 = 'alku';
$lang['prev']                  = 'edellinen';
$lang['next']                  = 'seuraava';
$lang['last']                  = 'viimeinen';
$lang['edit_usermissing']      = 'Valittua käyttäjää ei löytynyt. Käyttäjä on voitu päivittää tai poistaa muualta.';
$lang['user_notify']           = 'Tiedota käyttäjälle';
$lang['note_notify']           = 'Tiedotus lähetetään vain, jos käyttäjälle on määritelty uusi salasana.';
$lang['note_group']            = 'Uudelle käyttäjälle määritellään oletusryhmä (%s), jos ryhmää ei erikseen määritellä.';
$lang['note_pass']             = 'Salasana luodaan automaattisesti, mikäli kenttä jätetään tyhjäksi ja jos käyttäjän tiedotus on päällä.';
$lang['add_ok']                = 'Käyttäjä lisätty onnistuneesti';
$lang['add_fail']              = 'Käyttäjän lisäys epäonnistui';
$lang['notify_ok']             = 'Ilmoitus sähköpostilla lähetetty';
$lang['notify_fail']           = 'Ilmoitusta sähköpostilla ei voitu lähettää';
$lang['import_error_baduserid'] = 'Käyttäjätunnus puuttuu';
$lang['import_error_badname']  = 'Epäkelpo nimi';
$lang['import_error_badmail']  = 'Epäkelpo sähköpostiosoite';
$lang['import_error_upload']   = 'Tuonti epäonnistui. CSV-tiedostoa ei voitu ladata tai se on tyhjä.';
$lang['import_error_readfail'] = 'Tuonti epäonnistui. Ladattua tiedostoa ei voida lukea.';
$lang['import_error_create']   = 'Käyttäjää ei voida luoda.';
